# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: wallet.proto
# Protobuf Python Version: 6.30.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    30,
    2,
    '',
    'wallet.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cwallet.proto\x12\x06pactus\"p\n\x0b\x41\x64\x64ressInfo\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x1d\n\npublic_key\x18\x02 \x01(\tR\tpublicKey\x12\x14\n\x05label\x18\x03 \x01(\tR\x05label\x12\x12\n\x04path\x18\x04 \x01(\tR\x04path\"\xa5\x01\n\x0bHistoryInfo\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x12\n\x04time\x18\x02 \x01(\rR\x04time\x12!\n\x0cpayload_type\x18\x03 \x01(\tR\x0bpayloadType\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\x12\x16\n\x06\x61mount\x18\x05 \x01(\x03R\x06\x61mount\"U\n\x18GetAddressHistoryRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"S\n\x19GetAddressHistoryResponse\x12\x36\n\x0chistory_info\x18\x01 \x03(\x0b\x32\x13.pactus.HistoryInfoR\x0bhistoryInfo\"\xa1\x01\n\x14GetNewAddressRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x36\n\x0c\x61\x64\x64ress_type\x18\x02 \x01(\x0e\x32\x13.pactus.AddressTypeR\x0b\x61\x64\x64ressType\x12\x14\n\x05label\x18\x03 \x01(\tR\x05label\x12\x1a\n\x08password\x18\x04 \x01(\tR\x08password\"p\n\x15GetNewAddressResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x36\n\x0c\x61\x64\x64ress_info\x18\x02 \x01(\x0b\x32\x13.pactus.AddressInfoR\x0b\x61\x64\x64ressInfo\"o\n\x14RestoreWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08mnemonic\x18\x02 \x01(\tR\x08mnemonic\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"8\n\x15RestoreWalletResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"R\n\x13\x43reateWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08password\x18\x04 \x01(\tR\x08password\"2\n\x14\x43reateWalletResponse\x12\x1a\n\x08mnemonic\x18\x02 \x01(\tR\x08mnemonic\"4\n\x11LoadWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"5\n\x12LoadWalletResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"6\n\x13UnloadWalletRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"7\n\x14UnloadWalletResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\";\n\x1aGetValidatorAddressRequest\x12\x1d\n\npublic_key\x18\x01 \x01(\tR\tpublicKey\"7\n\x1bGetValidatorAddressResponse\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\"\x81\x01\n\x19SignRawTransactionRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\'\n\x0fraw_transaction\x18\x02 \x01(\tR\x0erawTransaction\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\"y\n\x1aSignRawTransactionResponse\x12%\n\x0etransaction_id\x18\x01 \x01(\tR\rtransactionId\x12\x34\n\x16signed_raw_transaction\x18\x02 \x01(\tR\x14signedRawTransaction\"9\n\x16GetTotalBalanceRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"_\n\x17GetTotalBalanceResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12#\n\rtotal_balance\x18\x02 \x01(\x03R\x0ctotalBalance\"\x85\x01\n\x12SignMessageRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08password\x18\x02 \x01(\tR\x08password\x12\x18\n\x07\x61\x64\x64ress\x18\x03 \x01(\tR\x07\x61\x64\x64ress\x12\x18\n\x07message\x18\x04 \x01(\tR\x07message\"3\n\x13SignMessageResponse\x12\x1c\n\tsignature\x18\x01 \x01(\tR\tsignature\"7\n\x14GetTotalStakeRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"Y\n\x15GetTotalStakeResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1f\n\x0btotal_stake\x18\x02 \x01(\x03R\ntotalStake\"R\n\x15GetAddressInfoRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\"\x9c\x01\n\x16GetAddressInfoResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x18\n\x07\x61\x64\x64ress\x18\x02 \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05label\x18\x03 \x01(\tR\x05label\x12\x1d\n\npublic_key\x18\x04 \x01(\tR\tpublicKey\x12\x12\n\x04path\x18\x05 \x01(\tR\x04path\"\x85\x01\n\x16SetAddressLabelRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x1a\n\x08password\x18\x03 \x01(\tR\x08password\x12\x18\n\x07\x61\x64\x64ress\x18\x04 \x01(\tR\x07\x61\x64\x64ress\x12\x14\n\x05label\x18\x05 \x01(\tR\x05label\"\x19\n\x17SetAddressLabelResponse\"\x13\n\x11ListWalletRequest\".\n\x12ListWalletResponse\x12\x18\n\x07wallets\x18\x01 \x03(\tR\x07wallets\"7\n\x14GetWalletInfoRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"\xbd\x01\n\x15GetWalletInfoResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\x18\n\x07version\x18\x02 \x01(\x03R\x07version\x12\x18\n\x07network\x18\x03 \x01(\tR\x07network\x12\x1c\n\tencrypted\x18\x04 \x01(\x08R\tencrypted\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12\x1d\n\ncreated_at\x18\x06 \x01(\x03R\tcreatedAt\"5\n\x12ListAddressRequest\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\"_\n\x13ListAddressResponse\x12\x1f\n\x0bwallet_name\x18\x01 \x01(\tR\nwalletName\x12\'\n\x04\x64\x61ta\x18\x02 \x03(\x0b\x32\x13.pactus.AddressInfoR\x04\x64\x61ta*\x84\x01\n\x0b\x41\x64\x64ressType\x12\x19\n\x15\x41\x44\x44RESS_TYPE_TREASURY\x10\x00\x12\x1a\n\x16\x41\x44\x44RESS_TYPE_VALIDATOR\x10\x01\x12\x1c\n\x18\x41\x44\x44RESS_TYPE_BLS_ACCOUNT\x10\x02\x12 \n\x1c\x41\x44\x44RESS_TYPE_ED25519_ACCOUNT\x10\x03\x32\x80\n\n\x06Wallet\x12I\n\x0c\x43reateWallet\x12\x1b.pactus.CreateWalletRequest\x1a\x1c.pactus.CreateWalletResponse\x12L\n\rRestoreWallet\x12\x1c.pactus.RestoreWalletRequest\x1a\x1d.pactus.RestoreWalletResponse\x12\x43\n\nLoadWallet\x12\x19.pactus.LoadWalletRequest\x1a\x1a.pactus.LoadWalletResponse\x12I\n\x0cUnloadWallet\x12\x1b.pactus.UnloadWalletRequest\x1a\x1c.pactus.UnloadWalletResponse\x12R\n\x0fGetTotalBalance\x12\x1e.pactus.GetTotalBalanceRequest\x1a\x1f.pactus.GetTotalBalanceResponse\x12[\n\x12SignRawTransaction\x12!.pactus.SignRawTransactionRequest\x1a\".pactus.SignRawTransactionResponse\x12^\n\x13GetValidatorAddress\x12\".pactus.GetValidatorAddressRequest\x1a#.pactus.GetValidatorAddressResponse\x12L\n\rGetNewAddress\x12\x1c.pactus.GetNewAddressRequest\x1a\x1d.pactus.GetNewAddressResponse\x12X\n\x11GetAddressHistory\x12 .pactus.GetAddressHistoryRequest\x1a!.pactus.GetAddressHistoryResponse\x12\x46\n\x0bSignMessage\x12\x1a.pactus.SignMessageRequest\x1a\x1b.pactus.SignMessageResponse\x12L\n\rGetTotalStake\x12\x1c.pactus.GetTotalStakeRequest\x1a\x1d.pactus.GetTotalStakeResponse\x12O\n\x0eGetAddressInfo\x12\x1d.pactus.GetAddressInfoRequest\x1a\x1e.pactus.GetAddressInfoResponse\x12R\n\x0fSetAddressLabel\x12\x1e.pactus.SetAddressLabelRequest\x1a\x1f.pactus.SetAddressLabelResponse\x12\x43\n\nListWallet\x12\x19.pactus.ListWalletRequest\x1a\x1a.pactus.ListWalletResponse\x12L\n\rGetWalletInfo\x12\x1c.pactus.GetWalletInfoRequest\x1a\x1d.pactus.GetWalletInfoResponse\x12\x46\n\x0bListAddress\x12\x1a.pactus.ListAddressRequest\x1a\x1b.pactus.ListAddressResponseB:\n\x06pactusZ0github.com/pactus-project/pactus/www/grpc/pactusb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'wallet_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\006pactusZ0github.com/pactus-project/pactus/www/grpc/pactus'
  _globals['_ADDRESSTYPE']._serialized_start=3028
  _globals['_ADDRESSTYPE']._serialized_end=3160
  _globals['_ADDRESSINFO']._serialized_start=24
  _globals['_ADDRESSINFO']._serialized_end=136
  _globals['_HISTORYINFO']._serialized_start=139
  _globals['_HISTORYINFO']._serialized_end=304
  _globals['_GETADDRESSHISTORYREQUEST']._serialized_start=306
  _globals['_GETADDRESSHISTORYREQUEST']._serialized_end=391
  _globals['_GETADDRESSHISTORYRESPONSE']._serialized_start=393
  _globals['_GETADDRESSHISTORYRESPONSE']._serialized_end=476
  _globals['_GETNEWADDRESSREQUEST']._serialized_start=479
  _globals['_GETNEWADDRESSREQUEST']._serialized_end=640
  _globals['_GETNEWADDRESSRESPONSE']._serialized_start=642
  _globals['_GETNEWADDRESSRESPONSE']._serialized_end=754
  _globals['_RESTOREWALLETREQUEST']._serialized_start=756
  _globals['_RESTOREWALLETREQUEST']._serialized_end=867
  _globals['_RESTOREWALLETRESPONSE']._serialized_start=869
  _globals['_RESTOREWALLETRESPONSE']._serialized_end=925
  _globals['_CREATEWALLETREQUEST']._serialized_start=927
  _globals['_CREATEWALLETREQUEST']._serialized_end=1009
  _globals['_CREATEWALLETRESPONSE']._serialized_start=1011
  _globals['_CREATEWALLETRESPONSE']._serialized_end=1061
  _globals['_LOADWALLETREQUEST']._serialized_start=1063
  _globals['_LOADWALLETREQUEST']._serialized_end=1115
  _globals['_LOADWALLETRESPONSE']._serialized_start=1117
  _globals['_LOADWALLETRESPONSE']._serialized_end=1170
  _globals['_UNLOADWALLETREQUEST']._serialized_start=1172
  _globals['_UNLOADWALLETREQUEST']._serialized_end=1226
  _globals['_UNLOADWALLETRESPONSE']._serialized_start=1228
  _globals['_UNLOADWALLETRESPONSE']._serialized_end=1283
  _globals['_GETVALIDATORADDRESSREQUEST']._serialized_start=1285
  _globals['_GETVALIDATORADDRESSREQUEST']._serialized_end=1344
  _globals['_GETVALIDATORADDRESSRESPONSE']._serialized_start=1346
  _globals['_GETVALIDATORADDRESSRESPONSE']._serialized_end=1401
  _globals['_SIGNRAWTRANSACTIONREQUEST']._serialized_start=1404
  _globals['_SIGNRAWTRANSACTIONREQUEST']._serialized_end=1533
  _globals['_SIGNRAWTRANSACTIONRESPONSE']._serialized_start=1535
  _globals['_SIGNRAWTRANSACTIONRESPONSE']._serialized_end=1656
  _globals['_GETTOTALBALANCEREQUEST']._serialized_start=1658
  _globals['_GETTOTALBALANCEREQUEST']._serialized_end=1715
  _globals['_GETTOTALBALANCERESPONSE']._serialized_start=1717
  _globals['_GETTOTALBALANCERESPONSE']._serialized_end=1812
  _globals['_SIGNMESSAGEREQUEST']._serialized_start=1815
  _globals['_SIGNMESSAGEREQUEST']._serialized_end=1948
  _globals['_SIGNMESSAGERESPONSE']._serialized_start=1950
  _globals['_SIGNMESSAGERESPONSE']._serialized_end=2001
  _globals['_GETTOTALSTAKEREQUEST']._serialized_start=2003
  _globals['_GETTOTALSTAKEREQUEST']._serialized_end=2058
  _globals['_GETTOTALSTAKERESPONSE']._serialized_start=2060
  _globals['_GETTOTALSTAKERESPONSE']._serialized_end=2149
  _globals['_GETADDRESSINFOREQUEST']._serialized_start=2151
  _globals['_GETADDRESSINFOREQUEST']._serialized_end=2233
  _globals['_GETADDRESSINFORESPONSE']._serialized_start=2236
  _globals['_GETADDRESSINFORESPONSE']._serialized_end=2392
  _globals['_SETADDRESSLABELREQUEST']._serialized_start=2395
  _globals['_SETADDRESSLABELREQUEST']._serialized_end=2528
  _globals['_SETADDRESSLABELRESPONSE']._serialized_start=2530
  _globals['_SETADDRESSLABELRESPONSE']._serialized_end=2555
  _globals['_LISTWALLETREQUEST']._serialized_start=2557
  _globals['_LISTWALLETREQUEST']._serialized_end=2576
  _globals['_LISTWALLETRESPONSE']._serialized_start=2578
  _globals['_LISTWALLETRESPONSE']._serialized_end=2624
  _globals['_GETWALLETINFOREQUEST']._serialized_start=2626
  _globals['_GETWALLETINFOREQUEST']._serialized_end=2681
  _globals['_GETWALLETINFORESPONSE']._serialized_start=2684
  _globals['_GETWALLETINFORESPONSE']._serialized_end=2873
  _globals['_LISTADDRESSREQUEST']._serialized_start=2875
  _globals['_LISTADDRESSREQUEST']._serialized_end=2928
  _globals['_LISTADDRESSRESPONSE']._serialized_start=2930
  _globals['_LISTADDRESSRESPONSE']._serialized_end=3025
  _globals['_WALLET']._serialized_start=3163
  _globals['_WALLET']._serialized_end=4443
# @@protoc_insertion_point(module_scope)
